summaryrefslogtreecommitdiffstats
path: root/libkdegames/kcanvasrootpixmap.h
diff options
context:
space:
mode:
Diffstat (limited to 'libkdegames/kcanvasrootpixmap.h')
-rw-r--r--libkdegames/kcanvasrootpixmap.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/libkdegames/kcanvasrootpixmap.h b/libkdegames/kcanvasrootpixmap.h
index 3eedb7e1..2da77746 100644
--- a/libkdegames/kcanvasrootpixmap.h
+++ b/libkdegames/kcanvasrootpixmap.h
@@ -26,13 +26,13 @@
class QCanvasView;
/**
* Implement KRootPixmap for a QCanvasView.
*
* The pixmap will be set as the background of the
* QCanvas associated with the view :
* <ul>
* <li>for correct positioning of the background pixmap, the given
* QCanvasView should be positioned at the origin of the canvas.</li>
* <li>no other view of the same canvas should use KCanvasRootPixmap.</li>
* <li>other views of the canvas will have the same background pixmap.</li>
* </ul>
@@ -45,13 +45,13 @@ class KDE_EXPORT KCanvasRootPixmap : public KRootPixmap
/**
* Constructor.
*/
- KCanvasRootPixmap(QCanvasView *view, const char *name = 0);
+ KCanvasRootPixmap(TQCanvasView *view, const char *name = 0);
private slots:
- void backgroundUpdatedSlot(const QPixmap &);
+ void backgroundUpdatedSlot(const TQPixmap &);
private:
- QCanvasView *_view;
+ TQCanvasView *_view;
class KCanvasRootPixmapPrivate;
KCanvasRootPixmapPrivate *d;
@@ -26,13 +26,13 @@
class QCanvasView;
/**
- * Implement KRootPixmap for a QCanvasView.
+ * Implement KRootPixmap for a TQCanvasView.
*
* The pixmap will be set as the background of the
@@ -26,13 +26,13 @@
*
* The pixmap will be set as the background of the
- * QCanvas associated with the view :
+ * TQCanvas associated with the view :
* <ul>
* <li>for correct positioning of the background pixmap, the given
@@ -26,13 +26,13 @@
* <ul>
* <li>for correct positioning of the background pixmap, the given
- * QCanvasView should be positioned at the origin of the canvas.</li>
+ * TQCanvasView should be positioned at the origin of the canvas.</li>
* <li>no other view of the same canvas should use KCanvasRootPixmap.</li>
* <li>other views of the canvas will have the same background pixmap.</li>